.. PySpeckle documentation master file, created by
   sphinx-quickstart on Sat Jun  8 10:44:22 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PySpeckle's documentation!
=====================================

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   client_api_ref

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
